@@ -1,5 +1,5 @@
 ;; -*- no-byte-compile: t; lexical-binding: nil -*-
-(define-package "nix-ts-mode" "0.1.5"
+(define-package "nix-ts-mode" "20251114.1500"
   "Major mode for Nix expressions, powered by tree-sitter."
   '((emacs "29.1"))
   :url "https://github.com/nix-community/nix-ts-mode"
